Documentation
¶
Overview ¶
Package utils provides utility functions for the goxis project.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BasicAuthHeader ¶ added in v1.6.7
Helper function for basic authentication
func Float64Ptr ¶
Float64Ptr returns a pointer to the given int value.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.